<?php
/**
 * Navigatable Behaviour
 *
 * Associates a model with the Menu.
 */
App::uses('Menu', 'Navigation.Model');

class NavigatableBehavior extends ModelBehavior {

	public $settings = array();


/**
 * Initialise the behavior - store the settings against the model
 *
 * @see ModelBehavior::setup()
 */
	public function setup(Model $Model, $settings = array()) {

		$this->settings[$Model->alias] = array_merge(
			array(
				'action' => 'view'
			),
			(array) $settings
		);

		return;

	}


/**
 * Insert the menu into find results.
 *
 * @see ModelBehavior::afterFind()
 */
	public function afterFind(Model $Model, $data, $primary=false) {

		$Menu = new Menu();

		foreach ($data as &$item) {

			if (isset($item[$Model->alias]) && ! empty($item[$Model->alias]['id'])) {

				$meta = $Menu->find('first', array(
					'conditions' => array(
						'model' => $Model->alias,
						'model_id' => $item[$Model->alias]['id']
					)
				));

				if (isset($meta['Menu'])) {

					$item['Menu'] = $meta['Menu'];

				}

			}

		}

		return $data;

	}


/**
 * Prepare the data for saving.
 *
 * @see ModelBehavior::beforeSave()
 */
	public function beforeSave(Model $Model, $options=array()) {

		$response = parent::beforeSave($Model, $options);

		if (isset($Model->data[$Model->alias]['Menu'])) {

			$Model->data['Menu'] = $Model->data[$Model->alias]['Menu'];
			unset($Model->data[$Model->alias]['Menu']);

		}

		return $response;

	}


/**
 * Save the menu
 *
 * @see ModelBehavior::afterSave()
 */
	public function afterSave(Model $Model, $created, $options=array()) {

		parent::afterSave($Model, $created, $options);

		// If we've got menu data we want to save it, unless this is a new menu
		// item that has been set as in active (basically it's not getting
		// added to the menu in this case).
		if (isset($Model->data['Menu']) && ($Model->data['Menu']['is_active'] || $Model->data['Menu']['id'])) {

			$Model->data['Menu']['model'] = $Model->alias;
			$Model->data['Menu']['action'] = $this->settings[$Model->alias]['action'];
			$Model->data['Menu']['model_id'] = $Model->id;

			$Menu = new Menu();
			$Menu->create();
			$Menu->save($Model->data);

		}

		return;

	}

}